@@ -185,6 +185,10 @@ class APIClient:
                             "Invalid value for 'version' provided in wml_credentials. Please check the wml_credentials provided." +
                             "Supported value for version field are: " + ', '.join(self.__wsd_supported_version_list))
 
+                    if 'instance_id' in wml_credentials.keys():
+                        raise WMLClientError(
+                            "Provided credentials are invalid. 'instance_id' should not be used in cloud scenario. Please check the wml_credentials provided.")
+
                     self.ICP = False
                     self.CAMS = False
 
@@ -273,8 +277,8 @@ class APIClient:
                 self.proceed = False
 
         if 'instance_id' in wml_credentials.keys() and \
-           (wml_credentials['instance_id'].lower() not in self.__predefined_instance_type_list) and \
-           'version' in wml_credentials.keys():
+                (wml_credentials['instance_id'].lower() not in self.__predefined_instance_type_list) and \
+                'version' in wml_credentials.keys():
             raise WMLClientError("Provided credentials are invalid. 'instance_id' and 'version' keys provided are not correct. Please check the wml_credentials provided."  )
 
         self.project_id = project_id
