@@ -1096,7 +1096,10 @@ class Deployments(WMLResource):
             return updated_details
 
     ## Below functions are for async scoring. They are just dummy functions.
-    def _score_async(self,deployment_uid, scoring_payload, transaction_id=None):
+    def _score_async(self,deployment_uid, scoring_payload,
+                     transaction_id=None,
+                     retention=None,
+                     platform_job_immediate=None):
 
         Deployments._validate_type(deployment_uid, u'deployment_id', STR_TYPE, True)
         Deployments._validate_type(scoring_payload, u'scoring_payload', dict, True)
@@ -1111,6 +1114,15 @@ class Deployments(WMLResource):
         else:
             params = None
 
+        if not self._client.ICP and retention is not None:
+            if not isinstance(retention, int) or retention < -1:
+                raise TypeError("`retention` takes integer values greater or equal than -1.")
+            params.update({'retention': retention})
+        if platform_job_immediate is not None:
+            if not isinstance(platform_job_immediate, bool):
+                raise TypeError("`platform_job_immediate` only takes boolean values.")
+            params.update({'platform_job_immediate': platform_job_immediate})
+
         if not self._ICP:
             response_scoring = self.session.post(
                 scoring_url,
@@ -1127,7 +1139,7 @@ class Deployments(WMLResource):
 
         return self._handle_response(202, u'scoring asynchronously', response_scoring)
 
-    def create_job(self, deployment_id, meta_props):
+    def create_job(self, deployment_id, meta_props, retention=None, platform_job_immediate=None):
         """
             Create an asynchronous deployment job.
 
@@ -1143,6 +1155,13 @@ class Deployments(WMLResource):
 
                    **type**: dict\n
 
+                #. **retention**: How many job days job meta should be retained (optional). Takes integer values >= -1.
+                                  Supported only on Cloud.\n
+                   **type**:: int\n
+
+                #. **platform_job_immediate**: Set the platform job task to syns or async mode (optinal).\n
+                   **type**: bool\n
+
             **Output**
 
             .. important::
@@ -1291,7 +1310,10 @@ class Deployments(WMLResource):
         else:
             payload.update({"deployment": {"href": "/v4/deployments/" + deployment_id}})
 
-        return self._score_async(deployment_id, payload, transaction_id=None)
+        return self._score_async(deployment_id, payload,
+                                 transaction_id=None,
+                                 retention=retention,
+                                 platform_job_immediate=platform_job_immediate)
 
     def get_job_details(self, job_uid=None, limit=None):
         """
