@@ -20,9 +20,10 @@ from ibm_watson_machine_learning.utils.autoai.enums import (
     TShirtSize, ClassificationAlgorithms, RegressionAlgorithms, ForecastingAlgorithms, PredictionType, Metrics,\
     Transformers, DataConnectionTypes, PipelineTypes, PositiveLabelClass)
 from ibm_watson_machine_learning.utils.autoai.errors import LocalInstanceButRemoteParameter, MissingPositiveLabel, \
-    NonForecastPredictionColumnMissing, ForecastPredictionColumnsMissing, ForecastingCannotBeRunAsLocalScenario
+    NonForecastPredictionColumnMissing, ForecastPredictionColumnsMissing, ForecastingCannotBeRunAsLocalScenario, \
+    TSNotSupported
 from ibm_watson_machine_learning.utils.autoai.utils import check_dependencies_versions, \
-    validate_additional_params_for_optimizer, is_list_composed_from_enum
+    validate_additional_params_for_optimizer, validate_optimizer_enum_values
 from ibm_watson_machine_learning.workspace import WorkSpace
 from .engines import WMLEngine
 from .optimizers import LocalAutoPipelines, RemoteAutoPipelines
@@ -69,7 +70,7 @@ class AutoAI(BaseExperiment):
     # note: initialization of AutoAI enums as class properties
     ClassificationAlgorithms = ClassificationAlgorithms
     RegressionAlgorithms = RegressionAlgorithms
-    _ForecastingAlgorithms = ForecastingAlgorithms
+    ForecastingAlgorithms = ForecastingAlgorithms
     TShirtSize = TShirtSize
     PredictionType = PredictionType
     Metrics = Metrics
@@ -139,9 +140,9 @@ class AutoAI(BaseExperiment):
                   *,
                   prediction_type: 'PredictionType',
                   prediction_column: str = None,
-                  #prediction_columns: List[str] = None,
-                  #timestamp_column_name: str = None,
-                  scoring: 'Metrics',
+                  prediction_columns: List[str] = None,
+                  timestamp_column_name: str = None,
+                  scoring: 'Metrics' = None,
                   desc: str = None,
                   test_size: float = None, # deprecated
                   holdout_size: float = 0.1,
@@ -150,10 +151,10 @@ class AutoAI(BaseExperiment):
                   include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms',
                                                       'ForecastingAlgorithms']] = None,
                   daub_include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None, # deprecated
-                  #backtest_num: int = None,
-                  #lookback_window: int = None,
-                  #forecast_window: int = None,
-                  #backtest_gap_length: int = None,
+                  backtest_num: int = None,
+                  lookback_window: int = None,
+                  forecast_window: int = None,
+                  backtest_gap_length: int = None,
                   cognito_transform_names: List['Transformers'] = None,
                   data_join_graph: 'DataJoinGraph' = None,
                   csv_separator: Union[List[str], str] = ',',
@@ -162,6 +163,8 @@ class AutoAI(BaseExperiment):
                   positive_label: str = None,
                   data_join_only: bool = False,
                   drop_duplicates: bool = True,
+                  # text_processing: bool = True,
+                  # word2vec_feature_number: int = None,
                   **kwargs) -> Union['RemoteAutoPipelines', 'LocalAutoPipelines']:
         """
         Initialize an AutoAi optimizer.
@@ -177,8 +180,14 @@ class AutoAI(BaseExperiment):
         prediction_column: str, required for multiclass, binary and regression prediction types
             Name of the target/label column
 
-        scoring: Metrics, required
-            Type of the metric to optimize with.
+        prediction_columns: List[str], required for forecasting prediction type
+            Names of the target/label columns.
+
+        timestamp_column_name: str, optional, used only for forecasting prediction type
+            Name of timestamp column for time series forecasting.
+
+        scoring: Metrics, optional
+            Type of the metric to optimize with. Not used for forecasting.
 
         desc: str, optional
             Description
@@ -205,6 +214,22 @@ class AutoAI(BaseExperiment):
             List of estimators to include in computation process.
             See: AutoAI.ClassificationAlgorithms, AutoAI.RegressionAlgorithms or AutoAI.ForecastingAlgorithms
 
+        backtest_num: int, optional
+            Used for forecasting prediction type. Configure number of backtests. Default value: 4
+            Value from range [0, 20]
+
+        lookback_window: int, optional
+            Used for forecasting prediction type. Configure length of lookback window. Default value: 10
+            If set to -1 lookback window will be auto-detected
+
+        forecast_window: int, optional
+            Used for forecasting prediction type. Configure length of forecast window. Default value: 1
+            Value from range [1, 60]
+
+        backtest_gap_length: int, optional
+            Used for forecasting prediction type. Configure gap between backtests. Default value: 0
+            Value from range [0, data length / 4]
+
         cognito_transform_names: List['Transformers'], optional
             List of transformers to include in feature enginnering computation process.
             See: AutoAI.Transformers
@@ -270,73 +295,40 @@ class AutoAI(BaseExperiment):
         >>>        desc="Some description.",
         >>>    )
         """
-        # Hidden documentation - to be recovered when TS will be officially supported:
+        # To be removed when Text Transformer enabled officially:
 
-        # prediction_columns: List[str], required for forecasting prediction type
-        #     Names of the target/label columns.
-
-        # timestamp_column_name: str, optional, used only for forecasting prediction type
-        #     Name of timestamp column for time series forecasting.
-
-        # backtest_num: int, optional
-        #     Used for forecasting prediction type. Configure number of backtests. Default value: 4
-        #     Value from range [0, 20]
-
-        # lookback_window: int, optional
-        #     Used for forecasting prediction type. Configure length of lookback window. Default value: 10
-        #     If set to -1 lookback window will be auto-detected
-
-        # forecast_window: int, optional
-        #     Used for forecasting prediction type. Configure length of forecast window. Default value: 1
-        #     Value from range [1, 60]
-
-        # backtest_gap_length: int, optional
-        #     Used for forecasting prediction type. Configure gap between backtests. Default value: 0
-        #     Value from range [0, data length / 4]
-
-        ## To be removed when TS enabled oficially:
-        if prediction_type == PredictionType._FORECASTING \
-            and ('ts_enabled' not in self._workspace.wml_client.wml_credentials
-                 or not self._workspace.wml_client.wml_credentials['ts_enabled']):
-            raise NotImplementedError()
-
-        prediction_columns = kwargs.get('prediction_columns')
-        timestamp_column_name = kwargs.get('timestamp_column_name')
-
-        backtest_num = kwargs.get('backtest_num')
-        lookback_window = kwargs.get('lookback_window')
-        forecast_window = kwargs.get('forecast_window')
-        backtest_gap_length = kwargs.get('backtest_gap_length')
+            # text_processing: bool, optional
+            #     If True text processing will be enabled. Default is True.
+            #
+            # word2vec_feature_number: int, optional
+            #     Number of features which will be generated from text column. Will be applied only if `text_processing`
+            #     is True. If `None` the default value will be taken.
 
+        if 'tt_enabled' in self._workspace.wml_client.wml_credentials \
+                or self._workspace.wml_client.wml_credentials.get('tt_enabled'):
+            text_processing = kwargs.get('text_processing')
+            word2vec_feature_number = kwargs.get('word2vec_feature_number')
+        else:
+            text_processing = None
+            word2vec_feature_number = None
         try:
-            del kwargs['prediction_columns']
+            del kwargs['text_processing']
         except:
             pass
         try:
-            del kwargs['timestamp_column_name']
+            del kwargs['word2vec_feature_number']
         except:
             pass
 
-        try:
-            del kwargs['backtest_num']
-        except:
-            pass
-        try:
-            del kwargs['lookback_window']
-        except:
-            pass
-        try:
-            del kwargs['forecast_window']
-        except:
-            pass
-        try:
-            del kwargs['backtest_gap_length']
-        except:
-            pass
+        # - end of Text Transformer section
 
-        ## - end of section
+        if prediction_type == PredictionType.FORECASTING and self._workspace.wml_client.ICP and \
+                (self._workspace.wml_client.wml_credentials['version'].startswith('2.5') or \
+                        self._workspace.wml_client.wml_credentials['version'].startswith('3.0') or \
+                        self._workspace.wml_client.wml_credentials['version'].startswith('3.5')):
+            raise TSNotSupported()
 
-        if prediction_type == PredictionType._FORECASTING:
+        if prediction_type == PredictionType.FORECASTING:
             if prediction_column is not None or prediction_columns is None:
                 raise ForecastPredictionColumnsMissing()
         else:
@@ -355,12 +347,14 @@ class AutoAI(BaseExperiment):
                 include_only_estimators = daub_include_only_estimators
             daub_include_only_estimators = None
 
-        for (sequence, enum_class) in (
-                (daub_include_only_estimators,
-                 AutoAI.RegressionAlgorithms if prediction_type == AutoAI.PredictionType.REGRESSION
-                    else AutoAI.ClassificationAlgorithms),
-                (cognito_transform_names, AutoAI.Transformers)):
-            is_list_composed_from_enum(sequence, enum_class)
+        validate_optimizer_enum_values(
+            prediction_type=prediction_type,
+            daub_include_only_estimators=daub_include_only_estimators,
+            include_only_estimators=include_only_estimators,
+            cognito_transform_names=cognito_transform_names,
+            scoring=scoring,
+            t_shirt_size=kwargs.get("t_shirt_size", TShirtSize.M)
+        )
 
         if data_join_graph:
             data_join_graph.problem_type = prediction_type
@@ -378,7 +372,7 @@ class AutoAI(BaseExperiment):
                        "\"t_shirt_size\" parameter is only applicable to the RemoteOptimizer instance."
             )
         elif self._workspace is None:
-            if prediction_type == PredictionType._FORECASTING:
+            if prediction_type == PredictionType.FORECASTING:
                 raise ForecastingCannotBeRunAsLocalScenario()
 
             reduced_kwargs = copy.copy(kwargs)
@@ -441,6 +435,8 @@ class AutoAI(BaseExperiment):
                 cognito_transform_names=cognito_transform_names,
                 data_join_graph=data_join_graph,
                 drop_duplicates=drop_duplicates,
+                text_processing=text_processing,
+                word2vec_feature_number=word2vec_feature_number,
                 csv_separator=csv_separator,
                 excel_sheet=excel_sheet,
                 encoding=encoding,
