@@ -18,11 +18,13 @@ from pandas import DataFrame, MultiIndex
 import json
 from time import sleep
 import warnings
+import logging
 
+from lomond import WebSocket
 from ibm_watson_machine_learning.utils.autoai.enums import (
     PredictionType, RegressionAlgorithms, ClassificationAlgorithms, RunStateTypes)
 from ibm_watson_machine_learning.utils.autoai.errors import PipelineNotLoaded, FitNeeded, InvalidPredictionType, \
-    AutoAIComputeError, ForecastingUnsupportedOperation, NoAvailableMetrics
+    AutoAIComputeError, ForecastingUnsupportedOperation, NoAvailableMetrics, LibraryNotCompatible
 from ibm_watson_machine_learning.wml_client_error import ApiRequestFailure
 from ibm_watson_machine_learning.utils.autoai.progress_bar import ProgressBar
 from ibm_watson_machine_learning.utils.autoai.utils import (
@@ -40,6 +42,8 @@ __all__ = [
     "WMLEngine"
 ]
 
+logging.getLogger('lomond').setLevel(logging.CRITICAL)
+
 
 class WMLEngine(BaseEngine):
     """
@@ -87,7 +91,7 @@ class WMLEngine(BaseEngine):
                             'encoding': self._auto_pipelines_parameters.get('encoding'),
                             'drop_duplicates': self._auto_pipelines_parameters.get('drop_duplicates'),
                             'optimization': {
-                                'learning_type': 'timeseries' if self._auto_pipelines_parameters.get('prediction_type') == PredictionType._FORECASTING else self._auto_pipelines_parameters.get('prediction_type'),
+                                'learning_type': 'timeseries' if self._auto_pipelines_parameters.get('prediction_type') == PredictionType.FORECASTING else self._auto_pipelines_parameters.get('prediction_type'),
                                 'max_num_daub_ensembles': self._auto_pipelines_parameters.get('max_num_daub_ensembles'),
                                 'cognito_transform_names':
                                     self._auto_pipelines_parameters.get('cognito_transform_names'),
@@ -101,7 +105,7 @@ class WMLEngine(BaseEngine):
                 }],
                 'runtimes': [{
                     'id': 'autoai',
-                    'name': 'auto_ai.kb' if self._auto_pipelines_parameters.get('prediction_type') != PredictionType._FORECASTING else 'auto_ai.ts',
+                    'name': 'auto_ai.kb' if self._auto_pipelines_parameters.get('prediction_type') != PredictionType.FORECASTING else 'auto_ai.ts',
                     'app_data': {
                         'wml_data': {
                             'hardware_spec': {}
@@ -112,7 +116,25 @@ class WMLEngine(BaseEngine):
             }
         }
 
-        if self._auto_pipelines_parameters.get('prediction_type') == PredictionType._FORECASTING:
+        # To be modified when text transformer will be supported.
+        # Copy setting these text transformer params setup without if in dictionary above in _wml_pipeline_metadata
+        #
+
+        if self._auto_pipelines_parameters.get('text_processing') is not None:
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                'text_processing_flag'] = self._auto_pipelines_parameters.get('text_processing')
+
+        if self._auto_pipelines_parameters.get('word2vec_feature_number') is not None:
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                'text_processing_options'] = {'word2vec':
+                                            {'output_dim': self._auto_pipelines_parameters.get('word2vec_feature_number')}}
+
+        # end of section
+
+
+        if self._auto_pipelines_parameters.get('prediction_type') == PredictionType.FORECASTING:
             self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                 'pipelines'][0]['nodes'][0]['parameters']['optimization'][
                 'target_columns'] = self._auto_pipelines_parameters['prediction_columns']
@@ -142,9 +164,10 @@ class WMLEngine(BaseEngine):
             self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                 'pipelines'][0]['nodes'][0]['parameters']['optimization'][
                 'compute_pipeline_notebooks_flag'] = self._auto_pipelines_parameters.get('notebooks', False)
-            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
-                'pipelines'][0]['nodes'][0]['parameters']['optimization'][
-                'scorer_for_ranking'] = self._auto_pipelines_parameters.get('scoring')
+            if 'scoring' in self._auto_pipelines_parameters:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'scorer_for_ranking'] = self._auto_pipelines_parameters.get('scoring')
 
         if self._20_class_limit_removal_test:
             self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT]['pipelines'][0]['nodes'][0]['parameters'].update({
@@ -405,8 +428,6 @@ class WMLEngine(BaseEngine):
             elif self._wml_client.default_space_id:
                 url = f"{url}?space_id={self._wml_client.default_space_id}"
 
-            from lomond import WebSocket
-
             gen = ProgressGenerator()
             end = False
 
@@ -785,6 +806,9 @@ class WMLEngine(BaseEngine):
                 wml_client=self._wml_client
             )
 
+        except LibraryNotCompatible as e:
+            raise e
+
         except Exception as e:
             raise PipelineNotLoaded(
                 pipeline_name,
