@@ -27,7 +27,7 @@ from ibm_watson_machine_learning.utils.autoai.enums import (
 from ibm_watson_machine_learning.utils.autoai.errors import (
     FitNotCompleted, MissingDataPreprocessingStep, WrongDataJoinGraphNodeName, DataSourceSizeNotSupported,
     TrainingDataSourceIsNotFile, NoneDataConnection, PipelineNotLoaded, OBMForNFSIsNotSupported,
-    ForecastingUnsupportedOperation)
+    ForecastingUnsupportedOperation, LibraryNotCompatible)
 from ibm_watson_machine_learning.utils.autoai.utils import try_import_lale
 from ibm_watson_machine_learning.utils.autoai.wsd_ui import (
     save_computed_pipelines_for_ui, save_experiment_for_ui, save_metadata_for_ui)
@@ -119,8 +119,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  prediction_column: str,
                  prediction_columns: List[str],
                  timestamp_column_name: str,
-                 scoring: 'Metrics',
                  engine: 'WMLEngine',
+                 scoring: 'Metrics' = None,
                  desc: str = None,
                  holdout_size: float = 0.1,
                  max_num_daub_ensembles: int = 1,
@@ -139,6 +139,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  positive_label: str = None,
                  data_join_only: bool = False,
                  drop_duplicates: bool = True,
+                 text_processing: bool = True,
+                 word2vec_feature_number: int = None,
                  notebooks=False,
                  autoai_pod_version=None,
                  obm_pod_version=None,
@@ -146,7 +148,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         self.params = {
             'name': name,
             'desc': desc if desc else '',
-            'prediction_type': prediction_type,
+            'prediction_type': prediction_type if prediction_type != 'timeseries' else 'forecasting',
             'prediction_column': prediction_column,
             'prediction_columns': prediction_columns,
             'timestamp_column_name': timestamp_column_name,
@@ -171,6 +173,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             'notebooks': notebooks,
             'autoai_pod_version': autoai_pod_version,
             'obm_pod_version': obm_pod_version,
+            'text_processing': text_processing,
+            'word2vec_feature_number': word2vec_feature_number
         }
         self._engine: 'WMLEngine' = engine
         self._engine.initiate_remote_resources(params=self.params, **kwargs)
@@ -545,6 +549,10 @@ class RemoteAutoPipelines(BaseAutoPipelines):
 
         except ForecastingUnsupportedOperation as e:
             raise e
+
+        except LibraryNotCompatible as e:
+            raise e
+
         except Exception as e:
             raise PipelineNotLoaded(pipeline_name if pipeline_name is not None else 'best pipeline',
                                     reason=f"Pipeline with such a name probably does not exist. "
