@@ -199,7 +199,6 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
                 'prediction_column': kb_parameters.get('label'),
                 'prediction_columns': kb_parameters.get('target_columns'),
                 'timestamp_column_name': kb_parameters.get('timestamp_column'),
-                'scoring': kb_parameters['scorer_for_ranking'],
                 'holdout_size': kb_parameters['holdout_param'],
                 'max_num_daub_ensembles': kb_parameters['max_num_daub_ensembles'],
                 't_shirt_size': kb_wml_data['hardware_spec']['id'],
@@ -213,6 +212,9 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
 
             if kb_parameters.get('train_sample_rows_test_size'):
                 params['train_sample_rows_test_size'] = kb_parameters['train_sample_rows_test_size']
+            if kb_parameters.get('scoring'):
+                params['scoring'] = kb_parameters['scorer_for_ranking']
+
         else:
             params = {
                 'name': name,
