@@ -511,22 +511,30 @@ score = {}()
                     pass
                 raise WMLClientError('Exception during getting function code.', e)
 
-        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
-            function_content_url = self._href_definitions.get_function_href(function_uid) + "/code"
-        else:
-            function_content_url = self._href_definitions.get_function_href(function_uid) + "/content"
-
-        put_header = self._client._get_headers(no_content_type=True)
-        with open(content_path, 'rb') as data:
-            if not self._ICP:
-                response_definition_put = requests.put(function_content_url, data=data,
-                                                       params=self._client._params(), headers=put_header)
+        try:
+            if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
+                function_content_url = self._href_definitions.get_function_href(function_uid) + "/code"
             else:
-                response_definition_put = requests.put(function_content_url, data=data,
-                                                       params=self._client._params(), headers=put_header,
-                                                       verify=False)
-            if response_definition_put.status_code != 200 and response_definition_put.status_code != 204 and response_definition_put.status_code != 201:
-                raise WMLClientError(" Unable to update function content" + response_definition_put)
+                function_content_url = self._href_definitions.get_function_href(function_uid) + "/content"
+
+            put_header = self._client._get_headers(no_content_type=True)
+            with open(content_path, 'rb') as data:
+                if not self._ICP:
+                    response_definition_put = requests.put(function_content_url, data=data,
+                                                           params=self._client._params(), headers=put_header)
+                else:
+                    response_definition_put = requests.put(function_content_url, data=data,
+                                                           params=self._client._params(), headers=put_header,
+                                                           verify=False)
+                if response_definition_put.status_code != 200 and response_definition_put.status_code != 204 and response_definition_put.status_code != 201:
+                    raise WMLClientError(" Unable to update function content" + response_definition_put)
+        except Exception as e:
+            raise e
+        finally:
+            try:
+                os.remove(archive_name)
+            except:
+                pass
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def download(self, function_uid, filename='downloaded_function.gz', rev_uid=None):
