@@ -162,8 +162,13 @@ class BaseDataConnection(ABC):
     def _download_data_from_cos(self, cos_client: 'resource') -> 'DataFrame':
         """Download training data for this connection. COS version"""
 
-        file = cos_client.Object(self.location.bucket,
-                                 self.location.path).get()
+        try:
+            file = cos_client.Object(self.location.bucket,
+                                     self.location.path).get()
+        except:
+            file = list(cos_client.Bucket(self.location.bucket).objects.filter(
+                Prefix=self.location.path))[0].get()
+
         buffer = io.BytesIO(file['Body'].read())
         data = try_load_dataset(buffer=buffer,
                                 sheet_name=self.auto_pipeline_params.get('excel_sheet', 0),
@@ -318,31 +323,38 @@ class BaseDataConnection(ABC):
         if not self._wml_client:
             raise CannotReadSavedRemoteDataBeforeFit()
 
-        # note: download data asset details
-        href = self._wml_client.connections._href_definitions.get_connection_by_id_href(connection_id) + '/assets'
-        params = self._wml_client._params().copy()
-        params['path'] = connection_path
-        params['fetch'] = 'metadata'
-        nfs_response = requests.get(href,
-                                    params=params,
+        # Note: workaround with volumes API as connections API changes data format
+        connection_details = self._wml_client.connections.get_details(connection_id)
+
+        href = self._wml_client.volumes._href_definitions.volume_upload_href(
+            connection_details['entity']['properties']['volume'])
+        full_href = f"{href[:-1]}{connection_path}"
+
+        csv_response = requests.get(full_href,
                                     headers=self._wml_client._get_headers(),
-                                    verify=False)
-
-        asset_details = self._wml_client.data_assets._handle_response(200, u'get nfs asset', nfs_response)
-
-        # note: read the column names of dataset
-        dataset_columns = [column['name'] for column in asset_details['fields']]
-
-        # note: stream the whole CSV file
-        params['fetch'] = 'data'
-        csv_response = requests.get(href,
-                                    params=params,
-                                    headers=self._wml_client._get_headers(),
-                                    verify=False)
+                                    verify=False,
+                                    stream=True)
 
+        # Note: if file is written in directory we need to create different href for download
         if csv_response.status_code != 200:
-            raise ApiRequestFailure(u'Failure during {}.'.format("downloading model"), csv_response)
+            path_parts = connection_path.split('/')
+            full_href = f"{href[:-1]}{'/'.join(path_parts[:-1])}%2F{path_parts[-1]}"
 
-        data = DataFrame(csv_response.json()['data'], columns=dataset_columns)
+            csv_response = requests.get(full_href,
+                                        headers=self._wml_client._get_headers(),
+                                        verify=False,
+                                        stream=True)
+
+            if csv_response.status_code != 200:
+                raise ApiRequestFailure(u'Failure during {}.'.format("downloading data"), csv_response)
+
+        downloaded_asset = csv_response.content
+        # note: read the csv/xlsx file from the memory directly into the pandas DataFrame
+        buffer = io.BytesIO(downloaded_asset)
+        data = try_load_dataset(buffer=buffer,
+                                sheet_name=self.auto_pipeline_params.get('excel_sheet', 0),
+                                separator=self.auto_pipeline_params.get('csv_separator', ','),
+                                encoding=self.auto_pipeline_params.get('encoding', 'utf-8')
+                                )
 
         return data
