@@ -21,6 +21,7 @@ REPO_MODELS_FRAMEWORKS_HREF_PATTERN = u'{}/v3/models/frameworks'
 INSTANCE_ENDPOINT_HREF_PATTERN = u'{}/v3/wml_instance'
 INSTANCE_BY_ID_ENDPOINT_HREF_PATTERN = u'{}/v3/wml_instances/{}'
 TOKEN_ENDPOINT_HREF_PATTERN = u'{}/v3/identity/token'
+CPD_TOKEN_ENDPOINT_HREF_PATTERN = u'{}/icp4d-api/v1/authorize'
 EXPERIMENTS_HREF_PATTERN = u'{}/v4/experiments'
 EXPERIMENT_HREF_PATTERN = u'{}/v4/experiments/{}'
 EXPERIMENT_RUNS_HREF_PATTERN = u'{}/v3/experiments/{}/runs'
@@ -183,6 +184,9 @@ class HrefDefinitions:
     def get_token_endpoint_href(self):
         return TOKEN_ENDPOINT_HREF_PATTERN.format(self._wml_credentials['url'])
 
+    def get_cpd_token_endpoint_href(self):
+        return CPD_TOKEN_ENDPOINT_HREF_PATTERN.format(self._wml_credentials['url'].replace(':31002', ':31843'))
+
     def get_published_model_href(self, model_uid):
         return PUBLISHED_MODEL_HREF_PATTERN.format(self._wml_credentials['url'] + self.prepend, model_uid)
 
