@@ -46,6 +46,7 @@ class ServiceInstanceNewPlan:
                                                  self._client.CAMS_URL,
                                                  self._client.ICP_PLATFORM_SPACES,
                                                  )
+
         self._client.wml_token = self._create_token()
         self._logger.info(u'Successfully prepared token: ' + self._client.wml_token)
         # ml_repository_client is initialized in repo
@@ -80,7 +81,7 @@ class ServiceInstanceNewPlan:
              A way you might use me is:
              >>> instance_details = client.service_instance.get_api_key()
         """
-        return self._wml_credentials['api_key']
+        return self._wml_credentials['apikey']
 
     def get_url(self):
         """
@@ -189,21 +190,13 @@ class ServiceInstanceNewPlan:
         else:
             return {}
 
-
     def _get_token(self):
         if self._client.wml_token is None:
             self._create_token()
             self._client.repository._refresh_repo_client()
-        else:
+        elif self._is_token_refresh_possible():
             if self._client.ICP:
-                token_url = self._wml_credentials['url'].replace(':31002', ':31843') + '/v1/preauth/validateAuth'
-                response = requests.get(token_url, auth=(self.get_username(), self.get_password()), verify=False)
-
-                if response.status_code == 200:
-                    token = response.json().get(u'accessToken')
-                else:
-                    raise WMLClientError(u'Error during getting token for the given credentials.', response)
-                return token
+                return self._get_cpd_token_from_request()
             elif self._client._is_IAM():
                 if self._get_expiration_datetime() - timedelta(minutes=50) < datetime.now():
                     self._client.wml_token = self._get_IAM_token()
@@ -225,27 +218,13 @@ class ServiceInstanceNewPlan:
             else:
                 raise WMLClientError('apikey for IAM token is not provided in credentials for the client.')
         else:
-            token_url = self._wml_credentials['url'].replace(':31002', ':31843') + '/v1/preauth/validateAuth'
-            response = requests.get(token_url, auth=(self.get_username(), self.get_password()), verify=False)
-
-            if response.status_code == 200:
-                token = response.json().get(u'accessToken')
-            else:
-                raise WMLClientError(u'Error during getting token for the given credentials.', response)
-            return token
+            return self._get_cpd_token_from_request()
 
     def _refresh_token(self):
-        import requests
         if self._client.proceed is True:
             self._client.wml_token = self._wml_credentials["token"]
 
-        token_url = self._wml_credentials['url'].replace(':31002', ':31843') + '/v1/preauth/validateAuth'
-        response = requests.get(token_url, auth=(self.get_username(), self.get_password()), verify=False)
-
-        if response.status_code == 200:
-            self._client.wml_token = response.json().get(u'accessToken')
-        else:
-            raise WMLClientError(u'Error during refreshing the token.', response)
+        self._client.wml_token = self._get_cpd_token_from_request()
 
     def _get_expiration_datetime(self):
         token_parts = self._client.wml_token.split('.')
@@ -282,4 +261,57 @@ class ServiceInstanceNewPlan:
             token = response.json().get(u'access_token')
         else:
             raise WMLClientError(u'Error during getting IAM Token.', response)
-        return token
\ No newline at end of file
+        return token
+
+    def _is_token_refresh_possible(self):
+        """
+        Checks if necessary credentials were passed for token refresh.
+        For CP4D we need (username & password)/(username & api_key).
+        For Cloud we need api_key.
+
+        **Output**
+            **returns**: True is token refresh can be performed False otherwise.
+            **return type**: bool
+        """
+        if self._client._is_IAM():
+            return 'apikey' in self._wml_credentials
+        else:
+            return 'username' in self._wml_credentials and (
+                    'password' in self._wml_credentials or 'apikey' in self._wml_credentials)
+
+    def _get_cpd_auth_pair(self):
+        """
+        Get pair of credentials required for generation of token.
+
+        **Output**
+
+            **returns**: String representing a dictionary of authentication credentials
+                         (username & password) or (username & api_key).\n
+            **return type**: str
+        """
+        if "apikey" in self._wml_credentials:
+            return f'{{\"username\": \"{self.get_username()}\", \"api_key\": \"{self.get_api_key()}\"}}'
+        else:
+            return f'{{\"username\": \"{self.get_username()}\", \"password\": \"{self.get_password()}\"}}'
+
+
+    def _get_cpd_token_from_request(self):
+        """
+        Send a request for token on CPD.
+
+        **Output**
+            **returns**: Newly created token if returned if no errors occurred.\n
+            **return type**: str\n
+        """
+        token_url = self._href_definitions.get_cpd_token_endpoint_href()
+        response = requests.post(token_url,
+                                 headers={
+                                     'Content-Type': 'application/json'
+                                 },
+                                 data=self._get_cpd_auth_pair(),
+                                 verify=False)
+
+        if response.status_code == 200:
+            return response.json().get(u'token')
+        else:
+            raise WMLClientError(u'Error during refreshing the token.', response)
