@@ -114,6 +114,7 @@ class Script(WMLResource):
                     **return type**: dict\n
 
                 **Example**
+
                  >>> metadata = {
                  >>>        client.script.ConfigurationMetaNamess.NAME: 'my first script',
                  >>>        client.script.ConfigurationMetaNames.DESCRIPTION: 'description of the script',
@@ -505,6 +506,7 @@ class Script(WMLResource):
             **Parameters**
 
             .. important::
+
                  #. **asset_uid**:  The Unique Id of the script asset to be downloaded\n
                     **type**: str\n
 
@@ -516,13 +518,14 @@ class Script(WMLResource):
 
             **Output**
 
+            .. important::
+
                  **returns**: Path to the downloaded asset content\n
                  **return type**: str\n
 
             **Example**
 
              >>> client.script.download(asset_uid,"script_file.zip")
-
          """
         if rev_uid is not None and self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Not applicable for this release')
@@ -612,7 +615,6 @@ class Script(WMLResource):
 
                    #. **asset_details**:  Metadata of the stored script asset\n
                       **type**: dict\n
-                      **type**: dict\n
 
                 **Output**
 
@@ -624,7 +626,6 @@ class Script(WMLResource):
                 **Example**
 
                      >>> asset_uid = client.script.get_id(asset_details)
-
         """
 
         return Script.get_uid(asset_details)
@@ -641,7 +642,6 @@ class Script(WMLResource):
 
                    #. **asset_details**:  Metadata of the stored script asset\n
                       **type**: dict\n
-                      **type**: dict\n
 
                 **Output**
 
@@ -653,7 +653,6 @@ class Script(WMLResource):
                 **Example**
 
                  >>> asset_uid = client.script.get_uid(asset_details)
-
         """
         Script._validate_type(asset_details, u'asset_details', object, True)
         Script._validate_type_of_details(asset_details, DATA_ASSETS_DETAILS_TYPE)
@@ -691,17 +690,25 @@ class Script(WMLResource):
 
         return WMLResource._get_required_element_from_dict(asset_details, u'asset_details', [u'metadata', u'href'])
 
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def update(self, script_uid, meta_props=None, file_path=None):
         """
-            Update script with either metadata or attachment or both.
+        Update script with either metadata or attachment or both.
 
-            :param script_uid:  Script UID
-            :type script_uid: str
+        **Parameters**
 
-            :returns: updated metadata of script
-            :rtype: dict
+        .. important::
+            #. **param script_uid**:  Script UID.\n
+               **type**: str\n
 
-            A way you might use me is:
+        **Output**
+
+        .. important::
+
+            **returns**: Updated metadata of script.\n
+            **return type**: dict\n
+
+        **Example**
 
             >>> script_details = client.script.update(model_uid, meta, content_path)
         """
@@ -936,16 +943,25 @@ class Script(WMLResource):
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create_revision(self, script_uid):
         """
-           Creates revision for the given script. Revisions are immutable once created.
-           The metadata and attachment at script_uid is taken and a revision is created out of it
+        Creates revision for the given script. Revisions are immutable once created.
+        The metadata and attachment at script_uid is taken and a revision is created out of it
 
-           :param script_uid: Script ID. Mandatory
-           :type script_uid: {str_type}
+        **Parameters**
 
-           :returns: stored script revisions metadata
-           :rtype: dict
+        .. important::
+            #. **script_uid**: Script ID. Mandatory.\n
+               **type**: str\n
 
-           >>> script_revision = client.scripts.create_revision(script_uid)
+        ** Output**
+
+        .. important::
+
+            **returns**: Stored script revisions metadata.\n
+            **return type**: dict\n
+
+        **Example**
+
+            >>> script_revision = client.scripts.create_revision(script_uid)
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
         # We need to enable this once we add functionality for WSD
@@ -985,18 +1001,26 @@ class Script(WMLResource):
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def list_revisions(self, script_uid, limit=None):
         """
-           List all revisions for the given script uid.
+        List all revisions for the given script uid.
 
-           :param script_uid: Stored script ID.
-           :type script_uid: {str_type}
+        **Parameters**
 
-           :param limit: limit number of fetched records (optional)
-           :type limit: int
+        .. important::
+            #. **script_uid**: Stored script ID.\n
+               **type**: str\n
 
-           :returns: stored script revisions details
-           :rtype: table
+            #. **limit**: Limit number of fetched records (optional).\n
+               **type**: int\n
 
-           >>> client.scripts.list_revisions(script_uid)
+        **Output**
+
+        .. important::
+                This method only prints the list of all script in a table format.\n
+                **return type**: None\n
+
+        **Example**
+
+            >>> client.scripts.list_revisions(script_uid)
         """
         # We need to enable this once we add functionality for WSD
         if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
@@ -1024,22 +1048,30 @@ class Script(WMLResource):
 
         self._list(script_values, [u'GUID', u'REVISION_ID', u'NAME', u'REVISION_COMMIT'], limit, _DEFAULT_LIST_LENGTH)
 
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_revision_details(self, script_uid=None, rev_uid=None):
         """
-           Get metadata of script_uid revision.
+        Get metadata of script_uid revision.
 
-           :param script_uid: Script ID. Mandatory
-           :type script_uid: {str_type}
+        **Paramaters**
 
-           :param rev_uid: Revision ID. If this parameter is not provided, returns latest revision if existing else error
-           :type rev_uid: int
+        .. important::
+            #. **script_uid**: Script ID. Mandatory.\n
+               **type**: str\n
 
-           :returns: stored script(s) metadata
-           :rtype: dict
+            #. **rev_uid**: Revision ID. If this parameter is not provided, returns latest revision if existing else error.\n
+               **type**: int\n
 
-           A way you might use me is:
+        **Output**
 
-           >>> script_details = client.scripts.get_revision_details(script_uid, rev_uid)
+        .. important::
+
+            **returns**: Stored script(s) metadata\n
+            **return type**: dict\n
+
+        **Example**
+
+            >>> script_details = client.scripts.get_revision_details(script_uid, rev_uid)
         """
         # We need to enable this once we add functionality for WSD
         if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
