@@ -90,7 +90,7 @@ class TestAutoAIRemote(unittest.TestCase):
     project_id = None
     space_id = None
 
-    space_name = 'tests_sdk_space'
+    space_name = 'autoai_tests_sdk_space'
 
     asset_id = None
 
@@ -263,6 +263,8 @@ class TestAutoAIRemote(unittest.TestCase):
             metrics = self.wml_client.training.get_details(self.run_id)['entity']['status'].get('metrics', [])
         # end note
 
+        status = self.remote_auto_pipelines.get_run_status()
+        self.assertNotIn(status, ['failed', 'canceled'], msg=f"Training finished with status {status}.")
         print("\n 1st pipeline completed")
         summary_df = self.remote_auto_pipelines.summary()
         print(summary_df)
