@@ -84,7 +84,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
     results_cos_path = 'results_wml_autoai'
 
-    space_name = 'tests_sdk_space'
+    space_name = 'autoai_tests_sdk_space'
 
     OPTIMIZER_NAME = 'CarPrice wml_autoai regression test'
     DEPLOYMENT_NAME = "CarPrice AutoAI Deployment tests"
@@ -198,7 +198,7 @@ class TestAutoAIRemote(unittest.TestCase):
             desc='test description',
             prediction_type=self.experiment.PredictionType.REGRESSION,
             prediction_column=self.prediction_column,
-            scoring=self.scoring_method,
+            # scoring=self.scoring_method,
             t_shirt_size=TShirtSize.S if self.wml_client.ICP else TShirtSize.L,
             autoai_pod_version=self.pod_version
         )
@@ -269,6 +269,11 @@ class TestAutoAIRemote(unittest.TestCase):
             metrics = training_details['entity']['status'].get('metrics', [])
         # end note
 
+        status_msg = training_details['entity']['status']
+        self.assertNotEqual(self.remote_auto_pipelines.get_run_status(), RunStateTypes.FAILED,
+                            msg="AutoAI run failed. Status message: {}".format(status_msg))
+
+        print(f"Run status = {self.remote_auto_pipelines.get_run_status()}")
         print("\n 1st pipeline completed")
         summary_df = self.remote_auto_pipelines.summary()
         print(summary_df)
