@@ -76,7 +76,7 @@ class TestAutoAIRemote(unittest.TestCase):
     OPTIMIZER_NAME = 'CreditRisk binary as sample notebook test'
     DEPLOYMENT_NAME = "CreditRisk AutoAI test Deployment "
 
-    space_name = 'tests_sdk_space'
+    space_name = 'autoai_tests_sdk_space'
 
     space_id = None
     project_id = None
