@@ -72,7 +72,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
     results_cos_path = 'results_wml_autoai'
 
-    space_name = 'tests_sdk_space'
+    space_name = 'autoai_tests_sdk_space'
 
     OPTIMIZER_NAME = 'Insurance wml_autoai regression test'
     DEPLOYMENT_NAME = "Insurance AutoAI Deployment tests"
