@@ -75,7 +75,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
     results_cos_path = 'results_wml_autoai'
 
-    space_name = 'tests_sdk_space'
+    space_name = 'autoai_tests_sdk_space'
 
     OPTIMIZER_NAME = 'Iris wml_autoai multiclass test'
     DEPLOYMENT_NAME = "Iris AutoAI Deployment tests"
@@ -194,7 +194,7 @@ class TestAutoAIRemote(unittest.TestCase):
             desc='test description',
             prediction_type=self.experiment.PredictionType.MULTICLASS,
             prediction_column='species',
-            scoring=self.experiment.Metrics.ACCURACY_SCORE,
+            # scoring=self.experiment.Metrics.ACCURACY_SCORE,
             test_size=0.15,
             max_number_of_estimators=1,
             csv_separator=self.custom_separator,
