@@ -74,7 +74,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
     results_cos_path = 'results_wml_autoai'
 
-    space_name = 'tests_sdk_space'
+    space_name = 'autoai_tests_sdk_space'
 
     OPTIMIZER_NAME = 'Iris wml_autoai multiclass test'
     DEPLOYMENT_NAME = "Iris AutoAI Deployment tests"
