@@ -1,6 +1,7 @@
 import unittest
 from sklearn.pipeline import Pipeline
 from lale.operators import TrainablePipeline
+from lale.lib.lale import Hyperopt
 import traceback
 
 from ibm_watson_machine_learning import APIClient
@@ -64,7 +65,7 @@ class TestAutoAIRemote(unittest.TestCase):
     project_id = None
     space_id = None
 
-    space_name = 'tests_sdk_space'
+    space_name = 'autoai_tests_sdk_space'
 
     connection_id = None
 
@@ -150,9 +151,14 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_06_get_train_data(self):
         TestAutoAIRemote.train_data = self.remote_auto_pipelines.get_data_connections()[0].read()
+
         print("train data sample:")
         print(self.train_data.head())
+
+        print(TestAutoAIRemote.train_data.dtypes)
+        
         self.assertGreater(len(self.train_data), 0)
+        self.assertCountEqual(TestAutoAIRemote.train_data.dtypes.sepal_length, 'float64')
 
     def test_07_get_run_status(self):
         status = self.remote_auto_pipelines.get_run_status()
@@ -223,6 +229,37 @@ class TestAutoAIRemote(unittest.TestCase):
 
         self.assertEqual(len(failed_pipelines), 0, msg=f"Some pipelines failed. Full list: {failed_pipelines}")
 
+    # @unittest.skip("Skipped lale pretty print")
+    def test_14b__pretty_print_lale__checks_if_generated_python_pipeline_code_is_correct(self):
+        pipeline_code = self.lale_pipeline.pretty_print()
+        try:
+            exec(pipeline_code)
+
+        except Exception as exception:
+            self.assertIsNone(exception,
+                              msg=f"Pretty print from lale pipeline was not successful \n\n Full pipeline code:\n {pipeline_code}")
+
+    def test_14c_remove_last_freeze_trainable_prefix_returned(self):
+        from lale.lib.sklearn import KNeighborsClassifier, DecisionTreeClassifier, LogisticRegression
+        prefix = self.lale_pipeline.remove_last().freeze_trainable()
+        self.assertIsInstance(prefix, TrainablePipeline,
+                              msg="Prefix pipeline is not of TrainablePipeline instance.")
+        TestAutoAIRemote.new_pipeline = prefix >> (KNeighborsClassifier| DecisionTreeClassifier| LogisticRegression)
+
+    def test_14d_hyperopt_fit_new_pipepiline(self):
+
+        X_values = self.train_data.drop(['species'], axis=1).values
+        y_values = self.train_data['species'].values
+        hyperopt = Hyperopt(estimator=TestAutoAIRemote.new_pipeline, cv=3, max_evals=2)
+        # try:
+        TestAutoAIRemote.hyperopt_pipelines = hyperopt.fit(X_values, y_values)
+        # except ValueError as e:
+        #     print(f"ValueError message: {e}")
+        #     traceback.print_exc()
+        #     hyperopt_results = hyperopt._impl._trials.results
+        #     print(hyperopt_results)
+        #     self.assertIsNone(e, msg="hyperopt fit was not successful")
+
     #################################
     #        HISTORICAL RUNS        #
     #################################
