@@ -76,7 +76,7 @@ class TestOBMOnly(unittest.TestCase):
     OPTIMIZER_NAME = 'OBM only test'
     DEPLOYMENT_NAME = "OBM only deployment test"
 
-    space_name = 'tests_sdk_space'
+    space_name = 'autoai_tests_sdk_space'
 
     job_id = None
 
