@@ -87,7 +87,7 @@ class TestOBMAndKB(unittest.TestCase):
     OPTIMIZER_NAME = 'OBM + KB test'
     DEPLOYMENT_NAME = "OBM + KB deployment test"
 
-    space_name = 'tests_sdk_space'
+    space_name = 'autoai_tests_sdk_space'
 
     job_id = None
 
