@@ -85,7 +85,7 @@ class TestAutoAIRemote(unittest.TestCase):
     project_id = None
     space_id = None
 
-    space_name = 'tests_sdk_space'
+    space_name = 'autoai_tests_sdk_space'
 
 
     @classmethod
