@@ -85,7 +85,7 @@ class TestAutoAIRemote(unittest.TestCase):
     project_id = None
     space_id = None
 
-    space_name = 'tests_sdk_space'
+    space_name = 'autoai_tests_sdk_space'
 
     asset_id = None
 
@@ -95,7 +95,6 @@ class TestAutoAIRemote(unittest.TestCase):
         Load WML credentials from config.ini file based on ENV variable.
         """
         cls.wml_credentials = get_wml_credentials()
-        cls.wml_credentials['ts_enabled'] = True
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
 
         if not cls.wml_client.ICP:
@@ -188,16 +187,15 @@ class TestAutoAIRemote(unittest.TestCase):
         TestAutoAIRemote.remote_auto_pipelines = self.experiment.optimizer(
             name=self.OPTIMIZER_NAME,
             desc='test description',
-            prediction_type=self.experiment.PredictionType._FORECASTING,
-            prediction_columns=[1], #[self.prediction_column],
-            timestamp_column_name=0,
+            prediction_type=self.experiment.PredictionType.FORECASTING,
+            prediction_columns=[self.prediction_column],
+            timestamp_column_name='timestamp',
             backtest_num=4,
             lookback_window=5,
             forecast_window=2,
-            scoring=PositiveLabelClass.PRECISION_SCORE_MICRO,
-            holdout_size=5, # TODO
+            holdout_size=0.05,
             max_number_of_estimators=1,
-            include_only_estimators=[AutoAI._ForecastingAlgorithms.ENSEMBLER],
+            include_only_estimators=[AutoAI.ForecastingAlgorithms.ENSEMBLER],
             t_shirt_size=TShirtSize.S if self.wml_client.ICP else TShirtSize.L,
             #autoai_pod_version="!<2.0.60",
             #csv_separator=','
