@@ -95,7 +95,7 @@ def get_space_id(wml_client, space_name, cos_resource_instance_id=None):
     """
     Return space id of existed or just created space named as `space_name`.
     """
-    spaces_details = wml_client.spaces.get_details().get('resources')
+    spaces_details = wml_client.spaces.get_details(limit=1000).get('resources')
     space_id = None
     for space_d in spaces_details:
         if space_d['entity']['name'] == space_name:
@@ -393,7 +393,7 @@ def setup_nfs_env(wml_credentials, dataset_file_name, remote_directory='datasets
     """, format='json')
 
     for e in res['resources']:
-        if e['entity']['properties']['volume'] == volume_name:
+        if e['entity']['properties'].get('volume') == volume_name:
             connection_id = e['metadata']['asset_id']
             break
 
