@@ -16,6 +16,8 @@ from __future__ import print_function
 import requests
 import json
 import re
+import logging
+from lomond import WebSocket
 from ibm_watson_machine_learning.utils import print_text_header_h1, print_text_header_h2, TRAINING_RUN_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, str_type_conv, meta_props_str_conv, group_metrics, StatusLogger
 import time
 from ibm_watson_machine_learning.metanames import TrainingConfigurationMetaNames, TrainingConfigurationMetaNamesCp4d30
@@ -24,6 +26,8 @@ from ibm_watson_machine_learning.href_definitions import is_uid
 from ibm_watson_machine_learning.wml_resource import WMLResource
 from ibm_boto3.exceptions import Boto3Error
 
+logging.getLogger('lomond').setLevel(logging.CRITICAL)
+
 
 class Training(WMLResource):
     """
@@ -864,7 +868,6 @@ class Training(WMLResource):
             self._COS_logs(training_uid,
                            lambda: print_text_header_h1(u'Log monitor started for training run: ' + str(training_uid)))
         else:
-            from lomond import WebSocket
             if not self._ICP:
                 if self._client.CLOUD_PLATFORM_SPACES:
                     ws_param = self._client._params()
@@ -949,7 +952,6 @@ class Training(WMLResource):
             self._COS_metrics(training_uid,
                            lambda: print_text_header_h1(u'Log monitor started for training run: ' + str(training_uid)))
         else:
-            from lomond import WebSocket
             if not self._ICP:
                 if self._client.CLOUD_PLATFORM_SPACES:
                     ws_param = self._client._params()
