@@ -74,7 +74,7 @@ class PredictionType:
     BINARY = "binary"
     MULTICLASS = "multiclass"
     REGRESSION = "regression"
-    _FORECASTING = "forecasting"
+    FORECASTING = "forecasting"
 
 
 class PositiveLabelClass:
