@@ -56,7 +56,8 @@ __all__ = [
     'ForecastingUnsupportedOperation',
     'OBMMainNodeAlreadySet',
     'InvalidSequenceValue',
-    'NoAvailableMetrics'
+    'NoAvailableMetrics',
+    'TSNotSupported'
 ]
 
 from ibm_watson_machine_learning.utils import WMLClientError
@@ -285,10 +286,15 @@ class OBMMainNodeAlreadySet(WMLClientError):
 
 class InvalidSequenceValue(WMLClientError, ValueError):
     def __init__(self, el, correct_values):
-        WMLClientError.__init__(self, f"Invalid sequence element: {el} sequence must be composed from"
+        WMLClientError.__init__(self, f"Invalid sequence element: '{el}' sequence must be composed from "
                                       f"given values: {correct_values}")
 
 
 class NoAvailableMetrics(WMLClientError):
     def __init__(self):
         WMLClientError.__init__(self, f"Currently there is no available metrics.")
+
+
+class TSNotSupported(WMLClientError):
+    def __init__(self):
+        WMLClientError.__init__(self, f"Time series forecasting is not supported for CPD 2.5, 3.0 and 3.5.")
