@@ -43,7 +43,8 @@ __all__ = [
     'try_import_joblib',
     'get_sw_spec_and_type_based_on_sklearn',
     'validate_additional_params_for_optimizer',
-    'is_list_composed_from_enum'
+    'is_list_composed_from_enum',
+    'validate_optimizer_enum_values'
 ]
 
 import io
@@ -65,6 +66,8 @@ import pkg_resources
 import requests
 from packaging import version
 
+from .enums import (RegressionAlgorithms, ClassificationAlgorithms, ForecastingAlgorithms, Transformers,
+                    Metrics, TShirtSize, PredictionType)
 from .errors import (MissingPipeline, DataFormatNotSupported, LibraryNotCompatible,
                      CannotInstallLibrary, CannotDownloadTrainingDetails, CannotDownloadWMLPipelineDetails,
                      VisualizationFailed, AdditionalParameterIsUnexpected, InvalidSequenceValue, NoAvailableMetrics)
@@ -130,8 +133,8 @@ def fetch_pipelines(run_params: dict,
         """
         Automate check all pipeline nodes to find xgboost or lightgbm dependency.
         """
-        xgboost_estimators = ['XGBClassifierEstimator', 'XGBRegressorEstimator']
-        lightgbm_estimators = ['LGBMClassifierEstimator', 'LGBMRegressorEstimator']
+        xgboost_estimators = ['XGBClassifierEstimator', 'XGBRegressorEstimator', 'XGBClassifier', 'XGBRegressor']
+        lightgbm_estimators = ['LGBMClassifierEstimator', 'LGBMRegressorEstimator', 'LGBMClassifier', 'LGBMRegressor']
 
         # note: check dependencies for estimators and other packages
         estimator_name = pipeline['context']['intermediate_model'].get('pipeline_nodes', [None])[-1]
@@ -1164,8 +1167,15 @@ def create_summary(details: dict, scoring: str) -> 'DataFrame':
             return details['entity']['status'].get('metrics', [{}])[0].get('ml_metrics', {}).keys()
         elif is_ts_metrics:
             names = list(['validation_' + x for x in details['entity']['status'].get('metrics', [{}])[0].get('ts_metrics', {}).get('training',{}).keys()])
-            holdout_names = list(['holdout_' + y for y in [x for x in details['entity']['status'].get('metrics', [{}]) if 'holdout' in x['ts_metrics']][0]['ts_metrics']['holdout'].keys()])
-            backtest_names = list(['backtest_' + y for y in [x for x in details['entity']['status'].get('metrics', [{}]) if 'backtest' in x['ts_metrics']][0]['ts_metrics']['backtest']['avg'].keys()])
+            try:
+                holdout_names = list(['holdout_' + y for y in [x for x in details['entity']['status'].get('metrics', [{}]) if 'holdout' in x['ts_metrics']][0]['ts_metrics']['holdout'].keys()])
+            except IndexError:
+                holdout_names = []
+            try:
+                backtest_names = list(['backtest_' + y for y in [x for x in details['entity']['status'].get('metrics', [{}]) if 'backtest' in x['ts_metrics']][0]['ts_metrics']['backtest']['avg'].keys()])
+            except IndexError:
+                backtest_names = []
+
 
             return names + holdout_names + backtest_names
 
@@ -1192,7 +1202,17 @@ def create_summary(details: dict, scoring: str) -> 'DataFrame':
 
         if pipeline['context']['phase'] == model_phase:
             if is_ml_metrics:
-                enhancements = ', '.join(pipeline['context']['intermediate_model']['composition_steps'])
+                enhancements = []
+                steps = pipeline['context']['intermediate_model']['composition_steps']
+
+                if any('hpo' in s for s in steps):
+                    enhancements.append('HPO')
+                if 'cognito' in steps:
+                    enhancements.append('FE')
+                if 'Text_FE' in steps:
+                    enhancements.append('Text_FE')
+
+                enhancements = ', '.join(enhancements)
             elif is_ts_metrics:
                 enhancements = 'HPO, FE'
 
@@ -1433,8 +1453,7 @@ def validate_additional_params_for_optimizer(params):
         'FE_drop_constant_columns_flag', 'FE_add_frequency_columns_flag', 'FE_add_missing_indicator_columns_flag',
         'data_provenance', 'target_label_name', 'preprocessor_data_filename', 'cognito_data_filename',
         'holdout_roc_curve_max_size', 'holdout_reg_pred_obs_max_size', 'max_estimator_n_jobs',
-        'enabled_feature_engineering_as_json', 'fairness_info', 'prediction_columns', 'timestamp_column_name',
-        'backtest_num', 'forecast_window', 'lookback_window', 'backtest_gap_length']
+        'enabled_feature_engineering_as_json', 'fairness_info', 'text_processing', 'word2vec_feature_number']
 
     for k in params:
         if k not in expected_params:
@@ -1495,9 +1514,9 @@ def is_list_composed_from_enum(sequence: List[Union[str, enum.Enum]],
     ----------
     sequence: List[Union[str, enum.Enum]
         Sequence of elements.
-    enum_class: Union[object, enum.Enum, List[enum.Enum]
+    enum_class: Union[object, enum.EnumMeta]
         Class for which validation will be performed.
-        It can be a class inheriting from enum.Enum or class with defined only defined class
+        It can be a class inheriting from enum.Enum or class which only contains
         attributes.
 
     Raises
@@ -1512,8 +1531,59 @@ def is_list_composed_from_enum(sequence: List[Union[str, enum.Enum]],
             enum_values = [attr_val for attr_name, attr_val in attributes
                            if not(attr_name.startswith('__') and attr_name.endswith('__'))]
 
-        print(enum_values)
         for el in sequence:
             el_value = el.value if isinstance(el, enum.Enum) else el
             if el_value not in enum_values:
                 raise InvalidSequenceValue(el, enum_values)
+
+
+def validate_optimizer_enum_values(
+        prediction_type: str,
+        daub_include_only_estimators: List[Union[ClassificationAlgorithms,
+                                                 RegressionAlgorithms,
+                                                 ForecastingAlgorithms]],
+        include_only_estimators: List[Union[ClassificationAlgorithms,
+                                                 RegressionAlgorithms,
+                                                 ForecastingAlgorithms]],
+        cognito_transform_names: List[Transformers],
+        scoring: str,
+        t_shirt_size: str) -> None:
+    """
+    Validate if passed optimizer variables takes values from defined enums.
+
+    Parameters
+    ----------
+    prediction_type: str
+        Type of the prediction.
+    daub_include_only_estimators: list
+        List of estimators.
+    include_only_estimators: list
+        List of estimators.
+    cognito_transform_names: list
+        List of transformers.
+    scoring: str
+        Type of the metric to optimize with.
+    t_shirt_size: str
+        The size of the remote AutoAI POD instance.
+
+    Raises
+    ------
+    InvalidSequenceValue, If element is not from enum class values.
+    """
+    if prediction_type == PredictionType.REGRESSION:
+        estimators_enum = RegressionAlgorithms
+    elif prediction_type == PredictionType.FORECASTING:
+        estimators_enum = ForecastingAlgorithms
+    else:
+        estimators_enum = ClassificationAlgorithms
+    for (sequence, enum_class) in (
+            ([prediction_type], PredictionType),
+            (daub_include_only_estimators, estimators_enum),
+            (include_only_estimators, estimators_enum),
+            (cognito_transform_names, Transformers),
+            ([t_shirt_size], TShirtSize)):
+        is_list_composed_from_enum(sequence, enum_class)
+
+    # Note: scoring can be None or have one of values from Metrics enum.
+    if scoring is not None:
+        is_list_composed_from_enum([scoring], Metrics)
