@@ -44,7 +44,7 @@ class Volume(WMLResource):
             **Parameters**
 
             .. important::
-                #. **volume_name**: Unique name  of the volume\n
+                #. **volume_id**: Unique ID of the volume.\n
                    **type**: str\n
 
             **Output**
@@ -55,7 +55,7 @@ class Volume(WMLResource):
 
             **Example**
 
-             >>> volume_details = client.volumes.get_details(volume_name)
+             >>> volume_details = client.volumes.get_details(volume_id)
 
         """
         Volume._validate_type(volume_id, u'volume_id', STR_TYPE, True)
@@ -473,7 +473,7 @@ class Volume(WMLResource):
             **Parameters**
 
             .. important::
-                #. **volume_name**:  Unique name of the volume
+                #. **volume_id**:  Unique ID of the volume.\n
                    **type**: str\n
 
             **Output**
@@ -484,7 +484,7 @@ class Volume(WMLResource):
 
             **Example**
 
-             >>> client.volumes.delete(volume_name)
+             >>> client.volumes.delete(volume_id)
 
         """
         Volume._validate_type(volume_id, u'asset_uid', STR_TYPE, True)
