@@ -13,9 +13,9 @@
 # limitations under the License.
 
 import requests
+import logging
 from ibm_watson_machine_learning.wml_client_error import MissingValue, WMLClientError, NoWMLCredentialsProvided, ApiRequestFailure, UnexpectedType, MissingMetaProp
 from ibm_watson_machine_learning.href_definitions import HrefDefinitions
-from ibm_watson_machine_learning.utils.log_util import get_logger
 from ibm_watson_machine_learning.utils import get_type_of_details, STR_TYPE, str_type_conv
 import urllib.parse
 import os
@@ -23,7 +23,7 @@ import sys
 
 class WMLResource:
     def __init__(self, name, client):
-        self._logger = get_logger(name)
+        self._logger = logging.getLogger(__name__)
         self._name = name
         self._WSD = None
         WMLResource._validate_type(client, u'client', object, True)
@@ -152,7 +152,7 @@ class WMLResource:
             expected_types = [expected_type]
 
         if not any([actual_type == exp_type for exp_type in expected_types]):
-            logger = get_logger(u'_validate_type_of_details')
+            logger = logging.getLogger(__name__)
             logger.debug(u'Unexpected type of \'{}\', expected: \'{}\', actual: \'{}\', occured for details: {}'.format(
                 u'details', expected_type, actual_type, details))
             raise UnexpectedType(u'details', expected_type, actual_type)
@@ -803,7 +803,7 @@ class WMLResource:
 
         # if (3 == sys.version_info.major) and (6 == sys.version_info.minor):
         #     if self._client.CLOUD_PLATFORM_SPACES or self._client.CLOUD_BETA_FLOW:
-        #         raise WMLClientError("Action not allowed!! Python 3.6 framework is deprecated and will be removed on Jan 20th, 2021."
-        #               "It will be read-only mode starting Nov 20th, 2020. i.e you won't be able to create or update new assets and deployment using this client."
+        #         raise WMLClientError("Action not allowed!! Python 3.6 framework is deprecated and will be removed on Jan 20th, 2021. "
+        #               "It will be read-only mode starting Nov 20th, 2020. i.e, you won't be able to create or update new assets and deployment using this client. "
         #               "Use Python 3.7 instead. For details, see https://dataplatform.cloud.ibm.com/docs/content/wsj/analyze-data/pm_service_supported_frameworks.html")
 
